![skpro](/docs/_static/logo/logo.png)

<p align="center">
  <a href="https://badge.fury.io/py/skpro"><img src="https://badge.fury.io/py/skpro.svg" alt="PyPI version" height="18"></a>
  <a href="https://travis-ci.org/alan-turing-institute/skpro"><img src="https://travis-ci.org/alan-turing-institute/skpro.svg?branch=master" alt="Build Status"></a>
  <a href="https://opensource.org/licenses/BSD-3-Clause"><img src="https://img.shields.io/badge/License-BSD%203--Clause-blue.svg" alt="License"></a>
</p>

A supervised domain-agnostic framework that allows for probabilistic modelling, namely the prediction of probability distributions for individual data points.

The package offers a variety of features and specifically allows for

- the implementation of probabilistic prediction strategies in the supervised contexts
- comparison of frequentist and Bayesian prediction methods
- strategy optimization through hyperparamter tuning and ensemble methods (e.g. bagging)
- workflow automation

List of [developers and contributors](AUTHORS.rst)

### Documentation

The full documentation is [available here](https://alan-turing-institute.github.io/skpro/).

### Installation

Installation is easy using Python's package manager

    $ pip install skpro

### Contributing & Citation

We welcome contributions to the skpro project. Please read our [contribution guide](/CONTRIBUTING.md).

If you use skpro in a scientific publication, we would appreciate [citations](CITATION.rst).


